@@ -69,12 +69,10 @@ enum {
 
 static guint signals[N_SIGNALS] = { 0, };
 
-static void alsa_device_class_init (AlsaDeviceClass *klass);
-static void alsa_device_init       (AlsaDevice      *device);
 static void alsa_device_dispose    (GObject         *object);
 static void alsa_device_finalize   (GObject         *object);
 
-G_DEFINE_TYPE (AlsaDevice, alsa_device, MATE_MIXER_TYPE_DEVICE)
+G_DEFINE_TYPE_WITH_PRIVATE (AlsaDevice, alsa_device, MATE_MIXER_TYPE_DEVICE)
 
 static const GList *      alsa_device_list_streams  (MateMixerDevice            *mmd);
 
@@ -181,16 +179,12 @@ alsa_device_class_init (AlsaDeviceClass *klass)
                       G_TYPE_NONE,
                       0,
                       G_TYPE_NONE);
-
-    g_type_class_add_private (object_class, sizeof (AlsaDevicePrivate));
 }
 
 static void
 alsa_device_init (AlsaDevice *device)
 {
-    device->priv = G_TYPE_INSTANCE_GET_PRIVATE (device,
-                                                ALSA_TYPE_DEVICE,
-                                                AlsaDevicePrivate);
+    device->priv = alsa_device_get_instance_private (device);
 
     device->priv->context = g_main_context_ref_thread_default ();
 
@@ -569,7 +563,7 @@ add_switch (AlsaDevice *device, AlsaStream *stream, snd_mixer_elem_t *el)
     MateMixerStreamSwitchRole role;
 
     count = snd_mixer_selem_get_enum_items (el);
-    if G_UNLIKELY (count <= 0) {
+    if (G_UNLIKELY (count <= 0)) {
         g_debug ("Skipping mixer switch %s with %d items",
                  snd_mixer_selem_get_name (el),
                  count);
@@ -579,7 +573,7 @@ add_switch (AlsaDevice *device, AlsaStream *stream, snd_mixer_elem_t *el)
     for (i = 0; i < count; i++) {
         gint ret = snd_mixer_selem_get_enum_item_name (el, i, sizeof (item), item);
 
-        if G_LIKELY (ret == 0) {
+        if (G_LIKELY (ret == 0)) {
             gint j;
             AlsaSwitchOption *option = NULL;
 
@@ -600,7 +594,7 @@ add_switch (AlsaDevice *device, AlsaStream *stream, snd_mixer_elem_t *el)
             g_warning ("Failed to read switch item name: %s", snd_strerror (ret));
     }
 
-    if G_UNLIKELY (options == NULL)
+    if (G_UNLIKELY (options == NULL))
         return;
 
     get_switch_info (el, &name, &label, &role);
