@@ -51,7 +51,7 @@ static void oss_stream_control_class_init (OssStreamControlClass *klass);
 static void oss_stream_control_init       (OssStreamControl      *control);
 static void oss_stream_control_finalize   (GObject               *object);
 
-G_DEFINE_TYPE (OssStreamControl, oss_stream_control, MATE_MIXER_TYPE_STREAM_CONTROL)
+G_DEFINE_TYPE_WITH_PRIVATE (OssStreamControl, oss_stream_control, MATE_MIXER_TYPE_STREAM_CONTROL)
 
 static guint                    oss_stream_control_get_num_channels     (MateMixerStreamControl  *mmsc);
 
@@ -110,15 +110,12 @@ oss_stream_control_class_init (OssStreamControlClass *klass)
     control_class->get_normal_volume    = oss_stream_control_get_normal_volume;
     control_class->get_base_volume      = oss_stream_control_get_base_volume;
 
-    g_type_class_add_private (object_class, sizeof (OssStreamControlPrivate));
 }
 
 static void
 oss_stream_control_init (OssStreamControl *control)
 {
-    control->priv = G_TYPE_INSTANCE_GET_PRIVATE (control,
-                                                 OSS_TYPE_STREAM_CONTROL,
-                                                 OssStreamControlPrivate);
+    control->priv = oss_stream_control_get_instance_private (control);
 }
 
 static void
@@ -192,7 +189,7 @@ oss_stream_control_load (OssStreamControl *control)
 
     g_return_if_fail (OSS_IS_STREAM_CONTROL (control));
 
-    if G_UNLIKELY (control->priv->fd == -1)
+    if (G_UNLIKELY (control->priv->fd == -1))
         return;
 
     ret = ioctl (control->priv->fd, MIXER_READ (control->priv->devnum), &v);
@@ -247,7 +244,7 @@ oss_stream_control_set_volume (MateMixerStreamControl *mmsc, guint volume)
 
     control = OSS_STREAM_CONTROL (mmsc);
 
-    if G_UNLIKELY (control->priv->fd == -1)
+    if (G_UNLIKELY (control->priv->fd == -1))
         return FALSE;
 
     return write_and_store_volume (control, OSS_VOLUME_JOIN_SAME (CLAMP (volume, 0, 100)));
@@ -284,7 +281,7 @@ oss_stream_control_set_channel_volume (MateMixerStreamControl *mmsc,
 
     control = OSS_STREAM_CONTROL (mmsc);
 
-    if G_UNLIKELY (control->priv->fd == -1)
+    if (G_UNLIKELY (control->priv->fd == -1))
         return FALSE;
 
     if (channel != LEFT_CHANNEL &&
@@ -348,7 +345,7 @@ oss_stream_control_set_balance (MateMixerStreamControl *mmsc, gfloat balance)
 
     control = OSS_STREAM_CONTROL (mmsc);
 
-    if G_UNLIKELY (control->priv->fd == -1)
+    if (G_UNLIKELY (control->priv->fd == -1))
         return FALSE;
 
     max = MAX (control->priv->volume[LEFT_CHANNEL],
