@@ -28,9 +28,6 @@
 #include "pulse-sink.h"
 #include "pulse-sink-control.h"
 
-static void pulse_sink_control_class_init (PulseSinkControlClass *klass);
-static void pulse_sink_control_init       (PulseSinkControl      *control);
-
 G_DEFINE_TYPE (PulseSinkControl, pulse_sink_control, PULSE_TYPE_STREAM_CONTROL);
 
 static gboolean      pulse_sink_control_set_mute        (PulseStreamControl *psc,
@@ -152,7 +149,7 @@ pulse_sink_control_create_monitor (PulseStreamControl *psc)
     sink = PULSE_SINK (mate_mixer_stream_control_get_stream (MATE_MIXER_STREAM_CONTROL (psc)));
 
     index = pulse_sink_get_index_monitor (sink);
-    if G_UNLIKELY (index == PA_INVALID_INDEX) {
+    if (G_UNLIKELY (index == PA_INVALID_INDEX)) {
         g_debug ("Monitor of stream control %s is not available",
                  mate_mixer_stream_control_get_name (MATE_MIXER_STREAM_CONTROL (psc)));
         return NULL;
