@@ -30,9 +30,6 @@
 #include "pulse-stream.h"
 #include "pulse-stream-control.h"
 
-static void pulse_sink_input_class_init (PulseSinkInputClass *klass);
-static void pulse_sink_input_init       (PulseSinkInput      *input);
-
 G_DEFINE_TYPE (PulseSinkInput, pulse_sink_input, PULSE_TYPE_STREAM_CONTROL);
 
 static guint         pulse_sink_input_get_max_volume (MateMixerStreamControl *mmsc);
@@ -228,7 +225,7 @@ pulse_sink_input_create_monitor (PulseStreamControl *psc)
     sink = PULSE_SINK (mate_mixer_stream_control_get_stream (MATE_MIXER_STREAM_CONTROL (psc)));
 
     index = pulse_sink_get_index_monitor (sink);
-    if G_UNLIKELY (index == PA_INVALID_INDEX) {
+    if (G_UNLIKELY (index == PA_INVALID_INDEX)) {
         g_debug ("Monitor of stream control %s is not available",
                  mate_mixer_stream_control_get_name (MATE_MIXER_STREAM_CONTROL (psc)));
         return NULL;
