@@ -49,8 +49,6 @@ enum {
 
 static GParamSpec *properties[N_PROPERTIES] = { NULL, };
 
-static void pulse_stream_control_class_init   (PulseStreamControlClass *klass);
-
 static void pulse_stream_control_get_property (GObject                 *object,
                                                guint                    param_id,
                                                GValue                  *value,
@@ -60,11 +58,10 @@ static void pulse_stream_control_set_property (GObject                 *object,
                                                const GValue            *value,
                                                GParamSpec              *pspec);
 
-static void pulse_stream_control_init         (PulseStreamControl      *control);
 static void pulse_stream_control_dispose      (GObject                 *object);
 static void pulse_stream_control_finalize     (GObject                 *object);
 
-G_DEFINE_ABSTRACT_TYPE (PulseStreamControl, pulse_stream_control, MATE_MIXER_TYPE_STREAM_CONTROL)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (PulseStreamControl, pulse_stream_control, MATE_MIXER_TYPE_STREAM_CONTROL)
 
 static MateMixerAppInfo *       pulse_stream_control_get_app_info         (MateMixerStreamControl   *mmsc);
 
@@ -178,8 +175,6 @@ pulse_stream_control_class_init (PulseStreamControlClass *klass)
                              G_PARAM_STATIC_STRINGS);
 
     g_object_class_install_properties (object_class, N_PROPERTIES, properties);
-
-    g_type_class_add_private (object_class, sizeof (PulseStreamControlPrivate));
 }
 
 static void
@@ -231,9 +226,7 @@ pulse_stream_control_set_property (GObject      *object,
 static void
 pulse_stream_control_init (PulseStreamControl *control)
 {
-    control->priv = G_TYPE_INSTANCE_GET_PRIVATE (control,
-                                                 PULSE_TYPE_STREAM_CONTROL,
-                                                 PulseStreamControlPrivate);
+    control->priv = pulse_stream_control_get_instance_private (control);
 
     /* Initialize empty volume and channel map structures, they will be used
      * if the stream does not support volume */
@@ -284,7 +277,7 @@ pulse_stream_control_get_stream_index (PulseStreamControl *control)
     g_return_val_if_fail (PULSE_IS_STREAM_CONTROL (control), PA_INVALID_INDEX);
 
     stream = mate_mixer_stream_control_get_stream (MATE_MIXER_STREAM_CONTROL (control));
-    if G_UNLIKELY (stream == NULL)
+    if (G_UNLIKELY (stream == NULL))
         return PA_INVALID_INDEX;
 
     return pulse_stream_get_index (PULSE_STREAM (stream));
@@ -329,7 +322,7 @@ pulse_stream_control_set_app_info (PulseStreamControl *control,
 {
     g_return_if_fail (PULSE_IS_STREAM_CONTROL (control));
 
-    if G_UNLIKELY (control->priv->app_info != NULL)
+    if (G_UNLIKELY (control->priv->app_info != NULL))
         _mate_mixer_app_info_free (control->priv->app_info);
 
     if (take == TRUE)
@@ -660,7 +653,7 @@ pulse_stream_control_set_monitor_enabled (MateMixerStreamControl *mmsc, gboolean
             control->priv->monitor =
                 PULSE_STREAM_CONTROL_GET_CLASS (control)->create_monitor (control);
 
-            if G_UNLIKELY (control->priv->monitor == NULL)
+            if (G_UNLIKELY (control->priv->monitor == NULL))
                 return FALSE;
 
             g_signal_connect (G_OBJECT (control->priv->monitor),
