@@ -64,8 +64,6 @@ enum {
 
 static guint signals[N_SIGNALS] = { 0, };
 
-static void mate_mixer_stream_class_init   (MateMixerStreamClass *klass);
-
 static void mate_mixer_stream_get_property (GObject              *object,
                                             guint                 param_id,
                                             GValue               *value,
@@ -75,11 +73,10 @@ static void mate_mixer_stream_set_property (GObject              *object,
                                             const GValue         *value,
                                             GParamSpec           *pspec);
 
-static void mate_mixer_stream_init         (MateMixerStream      *stream);
 static void mate_mixer_stream_dispose      (GObject              *object);
 static void mate_mixer_stream_finalize     (GObject              *object);
 
-G_DEFINE_ABSTRACT_TYPE (MateMixerStream, mate_mixer_stream, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (MateMixerStream, mate_mixer_stream, G_TYPE_OBJECT)
 
 static MateMixerStreamControl *mate_mixer_stream_real_get_control (MateMixerStream *stream,
                                                                    const gchar     *name);
@@ -195,8 +192,6 @@ mate_mixer_stream_class_init (MateMixerStreamClass *klass)
                       G_TYPE_NONE,
                       1,
                       G_TYPE_STRING);
-
-    g_type_class_add_private (object_class, sizeof (MateMixerStreamPrivate));
 }
 
 static void
@@ -276,9 +271,7 @@ mate_mixer_stream_set_property (GObject      *object,
 static void
 mate_mixer_stream_init (MateMixerStream *stream)
 {
-    stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (stream,
-                                                MATE_MIXER_TYPE_STREAM,
-                                                MateMixerStreamPrivate);
+    stream->priv = mate_mixer_stream_get_instance_private (stream);
 }
 
 static void
@@ -421,7 +414,7 @@ mate_mixer_stream_list_controls (MateMixerStream *stream)
 
     klass = MATE_MIXER_STREAM_GET_CLASS (stream);
 
-    if G_LIKELY (klass->list_controls != NULL)
+    if (G_LIKELY (klass->list_controls != NULL))
         return klass->list_controls (stream);
 
     return NULL;
@@ -440,7 +433,7 @@ mate_mixer_stream_list_switches (MateMixerStream *stream)
 
     klass = MATE_MIXER_STREAM_GET_CLASS (stream);
 
-    if G_LIKELY (klass->list_switches != NULL)
+    if (G_LIKELY (klass->list_switches != NULL))
         return klass->list_switches (stream);
 
     return NULL;
