@@ -47,8 +47,6 @@ enum {
 
 static GParamSpec *properties[N_PROPERTIES] = { NULL, };
 
-static void mate_mixer_switch_class_init   (MateMixerSwitchClass *klass);
-
 static void mate_mixer_switch_get_property (GObject              *object,
                                             guint                 param_id,
                                             GValue               *value,
@@ -58,11 +56,10 @@ static void mate_mixer_switch_set_property (GObject              *object,
                                             const GValue         *value,
                                             GParamSpec           *pspec);
 
-static void mate_mixer_switch_init         (MateMixerSwitch      *swtch);
 static void mate_mixer_switch_dispose      (GObject              *object);
 static void mate_mixer_switch_finalize     (GObject              *object);
 
-G_DEFINE_ABSTRACT_TYPE (MateMixerSwitch, mate_mixer_switch, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (MateMixerSwitch, mate_mixer_switch, G_TYPE_OBJECT)
 
 static MateMixerSwitchOption *mate_mixer_switch_real_get_option (MateMixerSwitch *swtch,
                                                                  const gchar     *name);
@@ -108,8 +105,6 @@ mate_mixer_switch_class_init (MateMixerSwitchClass *klass)
                              G_PARAM_STATIC_STRINGS);
 
     g_object_class_install_properties (object_class, N_PROPERTIES, properties);
-
-    g_type_class_add_private (object_class, sizeof (MateMixerSwitchPrivate));
 }
 
 static void
@@ -172,9 +167,7 @@ mate_mixer_switch_set_property (GObject      *object,
 static void
 mate_mixer_switch_init (MateMixerSwitch *swtch)
 {
-    swtch->priv = G_TYPE_INSTANCE_GET_PRIVATE (swtch,
-                                               MATE_MIXER_TYPE_SWITCH,
-                                               MateMixerSwitchPrivate);
+    swtch->priv = mate_mixer_switch_get_instance_private (swtch);
 }
 
 static void
